!  The code to calculate E/V of Fermi-gas including Hartree & Fock terms.
!  The two-fermion interaction is described with the potential "v2b".
!\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   module parts
   implicit none
   double precision, parameter :: pi = 3.141592653d0
   double precision, parameter :: hbarc = 197.329d0
   double precision, parameter :: amcc = 938.767d0
   double precision, parameter :: tol = 1.d-9
   double precision, parameter :: rmax = 50.d0
   double precision, parameter :: dr = 0.1d0
   integer, parameter :: nrmax = int(rmax/dr + tol)
   contains
!*******************************************************
   function v2b(r) result (ff) !MeV
!  The 2body-interaction
   implicit none
   double precision, intent(in) :: r
   double precision :: ff, v0, v1, a0, a1
   v0 =  200.d0 !MeV
   v1 = -15.d0 !MeV
   a0 =  1.5d0 !fm
   a1 =  3.5d0 !fm
   ff = v0*exp(-r*r/a0/a0) + v1*exp(-r*r/a1/a1)
   end function
!*******************************************************
   subroutine epera(xn, xp, ah, af)
   implicit none
   double precision, intent(in) :: xp, xn
   double precision, intent(out) :: ah, af
   double precision :: xs, w2, kf, r, x1
   integer :: ir
   xs = xp + xn ; w2 = xp*xp + xn*xn
   kf = (xs*1.5d0*pi*pi)**(1.d0/3.d0) + tol
   ah = 0.d0 ; af = 0.d0
   do ir = 1, nrmax
      r = dble(ir)*dr
      ah = ah + dr*r*r*v2b(r)
      x1 = kf*r
      x1 = (sin(x1)-x1*cos(x1))/x1/x1/x1
      af = af + dr*r*r*v2b(r)*x1*x1
   end do
   ah =  ah*4.d0*pi*w2/2.d0
   af = -af*4.d0*pi*w2*9.d0/8.d0
   end subroutine
!*******************************************************
   end module parts
!\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   program main
   use parts, only : epera, v2b, nrmax, dr
   implicit none
   integer :: ip, in, imax
   double precision :: xp, xn, dp, dn, ah, af
   open(101, file='edf_sym.out', status='replace', action='write')
   open(102, file='edf_neut.out', status='replace', action='write')
   open(103, file='edf_pandn.out', status='replace', action='write')
   open(104, file='edf_v2b.out', status='replace', action='write')

   imax = 60 ; dp = 0.005d0 ; dn = 0.005d0 !unit = (fm)**(-3)

   do in = 0, imax
      xn = dble(in)*dn ; xp = 0.d0
      call epera(xn, xn, ah, af)
      write(101,*) xn, ah+af, ah !sym. matter
      call epera(xn, xp, ah, af)
      write(102,*) xn, ah+af, ah !neutron matter
      do ip = 0, imax
         xp = dble(ip)*dp
         call epera(xn, xp, ah, af)
         write(103,*) xn, xp, ah+af
      end do
      write(103,*) ""
   end do

   do in = 0, nrmax
      xn = dr*dble(in)
      write(104,*) xn, v2b(xn)
   end do

   close(101)
   close(102)
   close(103)
   close(104)
   end program main
