!  The code to calculate E/V of the homogeneous nuclear matter.
!  Ref; Nucl. Phys. A 635, 231-256 (1998).
!\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   module SLy4
   implicit none
!--- Parameters in SLy4
   double precision, parameter :: t0 = -0.2488913d4
   double precision, parameter :: t1 =  0.486818d3
   double precision, parameter :: t2 = -0.546395d3
   double precision, parameter :: t3 =  0.13777d5
   double precision, parameter :: x0 =  0.834d0
   double precision, parameter :: x1 = -0.344d0
   double precision, parameter :: x2 = -1.d0
   double precision, parameter :: x3 =  1.354d0
   double precision, parameter :: alpha = 1.d0/6.d0
   double precision, parameter :: w0 = 123.d0 !unnecessary for the homogeneous nuclear matter.
   end module SLy4
!\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   module SLy6
   implicit none
!--- Parameters in SLy4
   double precision, parameter :: t0 = -0.24795d4
   double precision, parameter :: t1 =  0.46218d3
   double precision, parameter :: t2 = -0.44861d3
   double precision, parameter :: t3 =  0.13673d5
   double precision, parameter :: x0 =  0.825d0
   double precision, parameter :: x1 = -0.465d0
   double precision, parameter :: x2 = -1.d0
   double precision, parameter :: x3 =  1.355d0
   double precision, parameter :: alpha = 1.d0/6.d0
   double precision, parameter :: w0 = 122.d0 !unnecessary for the homogeneous nuclear matter.
   end module SLy6
!\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   module SkM_star
   implicit none
!--- Parameters in SLy4 (only those needed for nuclear matter)
   double precision, parameter :: t0 = -2645.d0
   double precision, parameter :: t1 =  410.d0
   double precision, parameter :: t2 = -135.d0
   double precision, parameter :: t3 =  15595.d0
   double precision, parameter :: x0 =  0.09d0
   double precision, parameter :: x1 =  0.d0
   double precision, parameter :: x2 =  0.d0
   double precision, parameter :: x3 =  0.d0
   double precision, parameter :: alpha = 1.d0/6.d0
   double precision, parameter :: w0 = 130.d0 !unnecessary for the homogeneous nuclear matter.
   end module SkM_star
!\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   module junk
   implicit none
   double precision, parameter :: pi = 3.141592653d0
   double precision, parameter :: hbarc = 197.329d0
   double precision, parameter :: amcc = 938.767d0
   double precision, parameter :: bitau = 0.6d0*((3.d0*pi*pi)**(2.d0/3.d0))
   contains
!*******************************************************
   function eov_k(xp,xn) result (ff)
!  The kinetic part of E/V for the nuclear matter, being common in any EDF.
   implicit none
   double precision, intent(in) :: xp, xn
   double precision :: ff, tp, tn
   tp = bitau*xp**(5.d0/3.d0) ; tn = bitau*xn**(5.d0/3.d0)
   ff = (0.5d0*hbarc*hbarc/amcc) * (tp+tn)
   end function eov_k
!*******************************************************
   function eov_Skyrme(xp,xn) result (ff) !(MeV/fm**3)
!  E/V of (rho_p, rho_n) for the nuclear matter with SLy4 except the kinetic part.
!  (xp,xn) are the spatially constant proton- and neutron-densities.
   use SkM_star !SLy4
   implicit none
   double precision, intent(inout) :: xp, xn
   double precision :: ff, xs, w2, tp, tn
   xs = xp + xn ; w2 = xp*xp + xn*xn
   tp = bitau*xp**(5.d0/3.d0) ; tn = bitau*xn**(5.d0/3.d0)
   ff = 0.5d0*t0 * ((1.d0 + 0.5*x0)*xs*xs - (0.5d0 + x0)*w2) &
      + (xs**alpha/12.d0)*t3 * ((1.d0 + 0.5*x3)*xs*xs - (0.5d0 + x3)*w2) &
      + 0.25d0*(  t1*(1.d0+0.5d0*x1) + t2*(1.d0+0.5d0*x2) ) * (tp+tn)*xs &
      + 0.25d0*( -t1*(0.5d0+x1)      + t2*(0.5d0+x2)      ) * (tp*xp + tn*xn)
   end function eov_Skyrme
!*******************************************************
   end module junk
!\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   program main
   use junk, only : eov_k, eov_Skyrme
   implicit none
   integer :: ip, in, imax
   double precision :: xp, xn, dp, dn
   imax = 60 ; dp = 0.005d0 ; dn = 0.005d0 !unit = (fm)**(-3)
   do in = 0, imax
      xn = dble(in)*dn ; xp = 0.d0
      write(21,*) xn, eov_k(xn,xn)+eov_Skyrme(xn,xn), eov_k(xn,xn) !sym. matter
      write(22,*) xn, eov_k(xp,xn)+eov_Skyrme(xp,xn), eov_k(xp,xn) !neutron matter
      do ip = 0, imax
         xp = dble(ip)*dp
         write(23,*) xn, xp, eov_k(xp,xn)+eov_Skyrme(xp,xn), eov_k(xp,xn)
      end do
      write(23,*) ""
   end do
   end program main
